Welcome to mirror list, hosted at ThFree Co, Russian Federation.

git.blender.org/blender.git - Unnamed repository; edit this file 'description' to name the repository.
summaryrefslogtreecommitdiff
diff options
context:
space:
mode:
authorWillian Padovani Germano <wpgermano@gmail.com>2003-06-24 11:21:17 +0400
committerWillian Padovani Germano <wpgermano@gmail.com>2003-06-24 11:21:17 +0400
commit06ee04fb05ff58e6e0a781b64100825ba7358f19 (patch)
treec90b1415ebb106090c6f94b4ee782146245bc67d /source/blender/python/api2_2x/Material.h
parenta0ea4df1ba0367657ba4e093ca0d1288d6258ba4 (diff)
* Added more doc files for epydoc and a test for the camera module.
* Moved public declarations in camera and lamp to a new file: bpy_types.h. * Fixed minor bugs in material, rgbTuple and Lamp + other minor changes. * Made part of the changes to conform to decided naming conventions.
Diffstat (limited to 'source/blender/python/api2_2x/Material.h')
-rw-r--r--source/blender/python/api2_2x/Material.h8
1 files changed, 4 insertions, 4 deletions
diff --git a/source/blender/python/api2_2x/Material.h b/source/blender/python/api2_2x/Material.h
index 437722fac37..6fd4c596618 100644
--- a/source/blender/python/api2_2x/Material.h
+++ b/source/blender/python/api2_2x/Material.h
@@ -39,18 +39,18 @@
#include "rgbTuple.h"
/*****************************************************************************/
/* Python C_Material structure definition: */
/*****************************************************************************/
typedef struct {
PyObject_HEAD
Material *material;
- C_rgbTuple *rgb, *amb, *spec, *mir;
+ BPy_rgbTuple *col, *amb, *spec, *mir;
-} C_Material;
+} BPy_Material;
extern PyTypeObject Material_Type; /* The Material PyType Object */
-#define C_Material_Check(v) \
+#define BPy_Material_Check(v) \
((v)->ob_type == &Material_Type) /* for type checking */
/*****************************************************************************/
@@ -39,18 +39,18 @@
#include "rgbTuple.h"
/*****************************************************************************/
-/* Python C_Material structure definition: */
+/* Python BPy_Material structure definition: */
/*****************************************************************************/
typedef struct {